@@ -6,10 +6,12 @@ export PYTHONUNBUFFERED=1
 SCRIPT_HOME="$(cd "$(dirname "$0")" && pwd)"
 BIFROST_HOME=$SCRIPT_HOME/..
 ANSIBLE_INSTALL_ROOT=${ANSIBLE_INSTALL_ROOT:-/opt/stack}
-ENABLE_VENV="false"
-USE_DHCP="false"
-USE_VENV="false"
-BUILD_IMAGE="false"
+USE_DHCP="${USE_DHCP:-false}"
+USE_VENV="${USE_VENV:-false}"
+BUILD_IMAGE="${BUILD_IMAGE:-false}"
+BAREMETAL_DATA_FILE=${BAREMETAL_DATA_FILE:-'/tmp/baremetal.json'}
+ENABLE_KEYSTONE="${ENABLE_KEYSTONE:-false}"
+ZUUL_BRANCH=${ZUUL_BRANCH:-}
 
 # Set defaults for ansible command-line options to drive the different
 # tests.
@@ -38,10 +40,9 @@ CREATE_IPA_IMAGE=false
 WRITE_INTERFACES_FILE=true
 PROVISION_WAIT_TIMEOUT=${PROVISION_WAIT_TIMEOUT:-900}
 NOAUTH_MODE=true
-ENABLE_KEYSTONE=false
 CLOUD_CONFIG=""
 WAIT_FOR_DEPLOY=true
-ZUUL_BRANCH=${ZUUL_BRANCH:-}
+ENABLE_VENV=false
 
 # This sets up the MySQL database like it's done for all OpenStack
 # projects for CI testing.
@@ -55,6 +56,9 @@ mysql_setup() {
     local DB_USER=openstack_citest
     local DB_PW=openstack_citest
 
+    # Make sure MySQL is running
+    sudo service mysql start || sudo service mysqld start || sudo service mariadb start
+
     sudo -H mysqladmin -u root password $DB_ROOT_PW
 
     # It's best practice to remove anonymous users from the database.  If
@@ -78,33 +82,21 @@ if [ "$ZUUL_BRANCH" != "" ] ; then
     mysql_setup
 fi
 
-# NOTE(cinerama): We could remove this if we change the CI job to use
-# USE_DHCP, BUILD_IMAGE, etc.
-SOURCE=$(basename ${BASH_SOURCE[0]})
-if [ $SOURCE = "test-bifrost-inventory-dhcp.sh" ]; then
-     USE_DHCP="true"
-elif [ $SOURCE = "test-bifrost-venv.sh" ]; then
-     USE_VENV="true"
-elif [ $SOURCE = "test-bifrost-build-images.sh" ]; then
-     BUILD_IMAGE="true"
-elif [ $SOURCE = "test-bifrost-keystone-auth.sh" ]; then
-     ENABLE_KEYSTONE="true"
-fi
-
 if [ ${USE_VENV} = "true" ]; then
     export VENV=/opt/stack/bifrost
-    export PATH=${VENV}/bin:${PATH}
     $SCRIPT_HOME/env-setup.sh
     # Note(cinerama): activate is not compatible with "set -u";
     # disable it just for this line.
     set +u
-    source /opt/stack/bifrost/bin/activate
+    source ${VENV}/bin/activate
     set -u
     ANSIBLE=${VENV}/bin/ansible-playbook
     ENABLE_VENV="true"
+    ANSIBLE_PYTHON_INTERP=${VENV}/bin/python
 else
     $SCRIPT_HOME/env-setup.sh
     ANSIBLE=${HOME}/.local/bin/ansible-playbook
+    ANSIBLE_PYTHON_INTERP=$(which python)
 fi
 
 # Adjust options for DHCP, VM, or Keystone tests
@@ -129,6 +121,11 @@ elif [ ${ENABLE_KEYSTONE} = "true" ]; then
     CLOUD_CONFIG="-e cloud_name=bifrost"
 fi
 
+logs_on_exit() {
+    $SCRIPT_HOME/collect-test-info.sh
+}
+trap logs_on_exit EXIT
+
 # Change working directory
 cd $BIFROST_HOME/playbooks
 
@@ -149,20 +146,27 @@ done
 ${ANSIBLE} -vvvv \
        -i inventory/localhost \
        test-bifrost-create-vm.yaml \
+       -e ansible_python_interpreter="${ANSIBLE_PYTHON_INTERP}" \
        -e test_vm_num_nodes=${TEST_VM_NUM_NODES} \
        -e test_vm_memory_size=${VM_MEMORY_SIZE} \
        -e test_vm_domain_type=${VM_DOMAIN_TYPE} \
+       -e baremetal_json_file=${BAREMETAL_DATA_FILE} \
        -e enable_venv=${ENABLE_VENV}
 
 if [ ${USE_DHCP} = "true" ]; then
-    # cut file to limit number of nodes to enroll for testing purposes
-    head -n -2 /tmp/baremetal.csv > /tmp/baremetal.csv.new && mv /tmp/baremetal.csv.new /tmp/baremetal.csv
+    # reduce the number of nodes in JSON file
+    # to limit number of nodes to enroll for testing purposes
+    python $BIFROST_HOME/scripts/split_json.py 3 \
+        ${BAREMETAL_DATA_FILE} \
+        ${BAREMETAL_DATA_FILE}.new \
+        ${BAREMETAL_DATA_FILE}.rest \
+        && mv ${BAREMETAL_DATA_FILE}.new ${BAREMETAL_DATA_FILE}
 fi
 
 set +e
 
 # Set BIFROST_INVENTORY_SOURCE
-export BIFROST_INVENTORY_SOURCE=/tmp/baremetal.csv
+export BIFROST_INVENTORY_SOURCE=${BAREMETAL_DATA_FILE}
 
 # Execute the installation and VM startup test.
 
@@ -184,6 +188,7 @@ ${ANSIBLE} -vvvv \
     -e noauth_mode=${NOAUTH_MODE} \
     -e enable_keystone=${ENABLE_KEYSTONE} \
     -e wait_for_node_deploy=${WAIT_FOR_DEPLOY} \
+    -e not_enrolled_data_file=${BAREMETAL_DATA_FILE}.rest \
     ${CLOUD_CONFIG}
 EXITCODE=$?
 
@@ -193,6 +198,4 @@ if [ $EXITCODE != 0 ]; then
     echo "****************************"
 fi
 
-$SCRIPT_HOME/collect-test-info.sh
-
 exit $EXITCODE
